"""
Allows for manual intervention into running jobs.
Current primary use case: Manually force a workflow to fail
"""
import argparse
import logging
import sys
from argparse import ArgumentParser

from .arbitrator import Arbiter

logger = logging.getLogger("mediator")
logger.setLevel(logging.INFO)
logger.addHandler(logging.StreamHandler(sys.stdout))


def parser() -> ArgumentParser:
    """
    Initialize argument parser for CLI

    :return: Argument Parser
    """
    arg_parser = ArgumentParser(
        description="System Mediator allows interventions in currently running Workspaces requests",
        formatter_class=argparse.RawTextHelpFormatter,
    )
    arg_parser.add_argument(
        "-ff",
        "--force-fail",
        nargs=1,
        action="store",
        required=False,
        help="Force a specified workflow into the failed state. Requires a workflow request id.",
    )
    arg_parser.add_argument(
        "-s",
        "--submit",
        nargs=1,
        action="store",
        required=False,
        help="Submit a specified workflow. Requires a workflow request id.",
    )
    return arg_parser


def main():
    """
    Launch the workspaces system mediator

    :return:
    """
    logger.info("**************************************")
    logger.info("* WELCOME TO THE WS SYSTEM MEDIATOR! *")
    logger.info("**************************************")

    args = parser().parse_args()

    Arbiter(args).intercede()
